/** */
window.addEventListener("DOMContentLoaded", (evt) => {
  // if the browser don't support the fullscreen api, then don't add the maximize button
  if (
    (!document.body.requestFullscreen) && 
    (!document.body.mozRequestFullScreen) &&
    (!document.body.webkitRequestFullscreen) &&
    (!document.body.msRequestFullscreen)
    ) {
      return;
  }

  // get all interactives and add a maximize button
  let interactives = document.querySelectorAll(".interactivo");
  interactives.forEach(inte => {
    let btn = document.createElement("button");
    inte.appendChild(btn);

    let parent = inte;
    btn.addEventListener("click", (evt) => {
      let iframe = parent.querySelector("iframe");
      iframe.style.width  = "";
      iframe.style.height = "";

      if (document.fullscreenElement) {
        document.exitFullscreen();
      } else if (document.webkitFullscreenElement) {
        document.webkitExitFullscreen();
      } else if (document.mozFullScreenElement) {
        document.mozExitFullscreen();
      }
      else {
        if (parent.requestFullscreen) {
          parent.requestFullscreen();
        } else if (inte.mozRequestFullScreen) {
          parent.mozRequestFullScreen();
        } else if (inte.webkitRequestFullscreen) {
          parent.webkitRequestFullscreen();
        } else if (inte.msRequestFullscreen) {
          parent.msRequestFullscreen();
        } else {
          return;
        }

        let width  = parseInt(screen.availWidth)  -40;
        let height = parseInt(screen.availHeight) -40;
        let ww, wh;

        if (window.matchMedia("(orientation: landscape)").matches) {
          ww = Math.max(width, height);
          wh = Math.min(width, height);
        }
        else {
          ww = Math.min(width, height);
          wh = Math.max(width, height);
        }

        let w = parseInt(iframe.getAttribute("width"));
        let h = parseInt(iframe.getAttribute("height"));
        let scaleToFit = Math.min(ww/w, wh/h);

        iframe.style.setProperty("--w", parseInt(w*scaleToFit) + "px");
        iframe.style.setProperty("--h", parseInt(h*scaleToFit) + "px");
      }
    });
  });

  function change_orientation(ele) {
    setTimeout(() => {
      let iframe = ele.querySelector("iframe");
      
      if (iframe) {
        let width  = parseInt(ele.offsetWidth)  -40;
        let height = parseInt(ele.offsetHeight) -40;
          let ww, wh;

          if (Math.abs(window.orientation) == 90) {
            ww = Math.max(width, height);
            wh = Math.min(width, height);
          }
          else {
            ww = Math.min(width, height);
            wh = Math.max(width, height);
          }

          let w = parseInt(iframe.getAttribute("width"));
          let h = parseInt(iframe.getAttribute("height"));
          let scaleToFit = Math.min(ww/w, wh/h);
  
          iframe.style.setProperty("--w", parseInt(w*scaleToFit) + "px");
          iframe.style.setProperty("--h", parseInt(h*scaleToFit) + "px");
      }
    }, 1);
  }

  window.addEventListener("orientationchange", (evt) => {
    if (document.fullscreenElement) {
      change_orientation(document.fullscreenElement);
    } else if (document.webkitFullscreenElement) {
      change_orientation(document.webkitFullscreenElement);
    } else if (document.mozFullScreenElement) {
      change_orientation(document.mozFullScreenElement);
    }
  });
});